@@ -1,5 +1,6 @@
 use fehler::throws;
 
+use notation_proto::prelude::BarLayer;
 use proc_macro2::TokenStream;
 use quote::{quote, ToTokens};
 use syn::parse::{Error, ParseStream};
@@ -37,3 +38,10 @@ impl ToTokens for LayerDsl {
         });
     }
 }
+
+impl LayerDsl {
+    pub fn to_proto(&self) -> BarLayer {
+        let slices = self.slices.iter().map(|x| x.to_proto()).collect();
+        BarLayer::new(self.track.id.clone(), slices)
+    }
+}
